# StreamType

The type of data stream to configure. When using `splunk-hec`:   - `endpointType` must be `http`.   - `customHeaders` must contain just one element with the key `token` and the value of the *Splunk HEC Token*.

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


